@@ -1,4 +1,4 @@
 from .oauth1 import OAuth1ConsumerBlueprint
 from .oauth2 import OAuth2ConsumerBlueprint
-from .base import oauth_authorized, oauth_error
+from .base import oauth_authorized, oauth_before_login, oauth_error
 from .requests import OAuth1Session, OAuth2Session
