@@ -2,10 +2,10 @@ from __future__ import unicode_literals, print_function
 import json
 
 import logging
-from lazy import lazy
 import flask
 from flask import request, url_for, redirect, current_app
 from werkzeug.wrappers import Response
+from werkzeug.utils import cached_property
 from oauthlib.oauth2 import MissingCodeError
 from .base import (
     BaseOAuthConsumerBlueprint,
@@ -14,6 +14,8 @@ from .base import (
     oauth_error,
 )
 from .requests import OAuth2Session
+from flask_dance.utils import invalidate_cached_property
+
 
 log = logging.getLogger(__name__)
 
@@ -51,7 +53,6 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         redirect_url=None,
         redirect_to=None,
         session_class=None,
-        backend=None,
         storage=None,
         **kwargs
     ):
@@ -125,7 +126,6 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
             root_path=root_path,
             login_url=login_url,
             authorized_url=authorized_url,
-            backend=backend,
             storage=storage,
         )
 
@@ -162,7 +162,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         # due to a bug in requests-oauthlib, we need to set this manually
         self.session._client.client_id = value
 
-    @lazy
+    @cached_property
     def session(self):
         """
         This is a session between the consumer (your website) and the provider
@@ -192,13 +192,11 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         return session
 
     def teardown_session(self, exception=None):
-        lazy.invalidate(self, "session")
+        invalidate_cached_property(self, "session")
 
     def login(self):
         log.debug("client_id = %s", self.client_id)
-        self.session.redirect_uri = url_for(
-            ".authorized", next=request.args.get("next"), _external=True
-        )
+        self.session.redirect_uri = url_for(".authorized", _external=True)
         url, state = self.session.authorization_url(
             self.authorization_url, state=self.state, **self.authorization_url_params
         )
@@ -215,9 +213,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         the provider (e.g. Twitter) after the user has logged into the
         provider's website and authorized your app to access their account.
         """
-        if "next" in request.args:
-            next_url = request.args["next"]
-        elif self.redirect_url:
+        if self.redirect_url:
             next_url = self.redirect_url
         elif self.redirect_to:
             next_url = url_for(self.redirect_to)
@@ -252,9 +248,7 @@ class OAuth2ConsumerBlueprint(BaseOAuthConsumerBlueprint):
         self.session._state = state
         del flask.session[state_key]
 
-        self.session.redirect_uri = url_for(
-            ".authorized", next=request.args.get("next"), _external=True
-        )
+        self.session.redirect_uri = url_for(".authorized", _external=True)
 
         log.debug("client_id = %s", self.client_id)
         log.debug("client_secret = %s", self.client_secret)
