@@ -22,14 +22,14 @@ def make_discord_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with Discord using OAuth 2. This requires
     a client ID and client secret from Discord. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables DISCORD_OAUTH_CLIENT_ID and DISCORD_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`DISCORD_OAUTH_CLIENT_ID` and
+    :envvar:`DISCORD_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on Discord.
@@ -69,7 +69,6 @@ def make_discord_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     discord_bp.from_config["client_id"] = "DISCORD_OAUTH_CLIENT_ID"
