@@ -23,14 +23,14 @@ def make_facebook_blueprint(
     authorized_url=None,
     rerequest_declined_permissions=False,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with Facebook using OAuth 2. This requires
     a client ID and client secret from Facebook. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables FACEBOOK_OAUTH_CLIENT_ID and FACEBOOK_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`FACEBOOK_OAUTH_CLIENT_ID` and
+    :envvar:`FACEBOOK_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on Facebook.
@@ -75,7 +75,6 @@ def make_facebook_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     facebook_bp.from_config["client_id"] = "FACEBOOK_OAUTH_CLIENT_ID"
