@@ -22,14 +22,14 @@ def make_github_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with GitHub using OAuth 2. This requires
     a client ID and client secret from GitHub. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables GITHUB_OAUTH_CLIENT_ID and GITHUB_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`GITHUB_OAUTH_CLIENT_ID` and
+    :envvar:`GITHUB_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on GitHub.
@@ -68,7 +68,6 @@ def make_github_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     github_bp.from_config["client_id"] = "GITHUB_OAUTH_CLIENT_ID"
