@@ -28,14 +28,14 @@ def make_slack_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with Slack using OAuth 2. This requires
     a client ID and client secret from Slack. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables SLACK_OAUTH_CLIENT_ID and SLACK_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`SLACK_OAUTH_CLIENT_ID` and
+    :envvar:`SLACK_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on Slack.
@@ -75,7 +75,6 @@ def make_slack_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     slack_bp.from_config["client_id"] = "SLACK_OAUTH_CLIENT_ID"
